.. _literal_example-name:

!!!!!!!!!!!!!!!
literal_example
!!!!!!!!!!!!!!!

.. meta::
   :keywords: literal_example, literal

.. index:: literal_example, literal

.. _literal_example-title:

Literal Command Example
#######################
This example is similar to the :ref:`dir_example-name` .

.. contents::
   :local:

.. meta::
   :keywords: factorial

.. index:: factorial

.. _literal_example@factorial:

factorial
*********

.. literalinclude:: ../../example/literal.cpp
   :lines: 6-6
   :language: cpp

.. meta::
   :keywords: square

.. index:: square

.. _literal_example@square:

square
******

.. literalinclude:: ../../example/literal.cpp
   :lines: 14-14
   :language: cpp

.. meta::
   :keywords: tangent

.. index:: tangent

.. _literal_example@tangent:

tangent
*******

.. literalinclude:: ../../example/literal.cpp
   :lines: 19-19
   :language: cpp

.. meta::
   :keywords: xrst_literal

.. index:: xrst_literal

.. _literal_example@xrst_literal:

xrst_literal
************
The file below demonstrates the use of ``xrst_literal`` .

.. _literal_example@This Example File:

This Example File
*****************

.. literalinclude:: ../../example/literal.cpp
   :language: cpp
